library DprExp;
uses
  ShareMem,
  Windows,
  Classes,
  Forms,
  Menus,
  ExptIntf,
  ToolIntf,
  VirtIntf,
  DprExpUnit in 'DprExpUnit.pas' {ExpertForm};

Type

  TOpenProjectExpert = class(TIExpert)
  private
    FExpertItem : TIMenuItemIntf;
    procedure ExpertItemClick(Sender : TIMenuItemIntf);
  public
    Constructor Create;
    Destructor Destroy; override;
    function GetName: string; override;
    function GetStyle: TExpertStyle; override;
    function GetState: TExpertState; override;
    function GetIDString: string; override;
  end;

// Implementation
//--------------------------------------------------------------------
// Name     : TOpenProjectExpert.Create
// Params   : 
// Return   :
// Descript :
//--------------------------------------------------------------------
Constructor TOpenProjectExpert.Create;
var
  MainMenu  : TIMainMenuIntf;
  MenuItems : TIMenuItemIntf;
  OpenItem  : TIMenuItemIntf;
  FileMenu  : TIMenuItemIntf;
begin
  inherited Create;
  MainMenu := ToolServices.GetMainMenu;
  if MainMenu <> nil then
  try
    MenuItems := MainMenu.GetMenuItems;
    if MenuItems <> nil then
    try
      OpenItem := MainMenu.FindMenuItem('FileOpenItem');
      if OpenItem <> nil then
      try
        FileMenu := OpenItem.GetParent;
        if FileMenu <> nil then
        try
          FExpertItem := FileMenu.InsertItem(OpenItem.GetIndex + 1,
            'Pro&jects...', 'ProjectsItem', '',
            ShortCut(VK_F12, [ssCtrl, ssAlt]), 0, 0, [mfVisible, mfEnabled],
            ExpertItemClick);
        finally
          FileMenu.Free;
        end;
      finally
        OpenItem.Free;
      end;
    finally
      MenuItems.Free;
    end;
  finally;
    MainMenu.Free;
  end;
end;

//--------------------------------------------------------------------
// Name     : TOpenProjectExpert.Destroy
// Params   :
// Return   :
// Descript :
//--------------------------------------------------------------------
Destructor TOpenProjectExpert.Destroy;
begin
  FExpertItem.Free;
  inherited Destroy;
end;

//--------------------------------------------------------------------
// Name     : TOpenProjectExpert.ExpertItemClick
// Params   :
// Return   :
// Descript :
//--------------------------------------------------------------------
procedure TOpenProjectExpert.ExpertItemClick(Sender: TIMenuItemIntf);
begin
  DPRExpert.Show;
  DPRExpert.SetFocus;
end;

//--------------------------------------------------------------------
// Name     : TOpenProjectExpert.GetName
// Params   :
// Return   :
// Descript :
//--------------------------------------------------------------------
function TOpenProjectExpert.GetName: string;
begin
  Result := 'Quick Project Open v1.0 by Alexandr G. Konopkin';
end;

//--------------------------------------------------------------------
// Name     : TOpenProjectExpert.GetStyle
// Params   :
// Return   :
// Descript :
//--------------------------------------------------------------------
function TOpenProjectExpert.GetStyle: TExpertStyle;
begin
  Result := esAddIn;
end;

//--------------------------------------------------------------------
// Name     : TOpenProjectExpert.GetState
// Params   :
// Return   :
// Descript :
//--------------------------------------------------------------------
function TOpenProjectExpert.GetState: TExpertState;
begin
  Result := [esEnabled];
end;

//--------------------------------------------------------------------
// Name     : TOpenProjectExpert.GetIDString
// Params   :
// Return   :
// Descript :
//--------------------------------------------------------------------
function TOpenProjectExpert.GetIDString: string;
begin
  Result := 'Alexandr_G_Konopkin.DPRExpert'
end;

//--------------------------------------------------------------------
// Name     : DoneExpert
// Params   :
// Return   :
// Descript :
//--------------------------------------------------------------------
procedure DoneExpert; export;
begin
end;

//--------------------------------------------------------------------
// Name     : InitExpert
// Params   :
// Return   :
// Descript :
//--------------------------------------------------------------------
function InitExpert(ToolServices  : TIToolServices;
                    RegisterProc  : TExpertRegisterProc;
                    var Terminate : TExpertTerminateProc) : boolean; export; stdcall;
begin
  Result := True;
  try
    ExptIntf.ToolServices := ToolServices;
    Application.Handle := ToolServices.GetParentHandle;
    RegisterProc(TOpenProjectExpert.Create);
  except
    ToolServices.RaiseException(ReleaseException);
  end;
end;

//--------------------------------------------------------------------
exports
  InitExpert name ExpertEntryPoint resident;

begin
end.
